Automatic Setup
~~~~~~~~~~~~~~~

In the following guides, you will configure Coiled to run Dask computations entirely within
your own cloud provider account using Coiled's command-line tools.

.. toctree::
   :maxdepth: 1
   :hidden:

   aws-cli
   gcp-cli

.. panels::
   :card: border-0
   :container: container-lg pb-3
   :column: col-md-6 col-md-6 p-2
   :body: text-center border-0
   :header: text-center border-0 h4 bg-white
   :footer: border-0 bg-white

   Use Coiled with AWS
   ^^^^^^^^^^^^^^^^^^^

   .. figure:: images/logo-aws.png
      :width: 35%
      :alt: Use Coiled with Amazon Web Services (AWS)

   +++

   .. link-button:: aws-cli
      :type: ref
      :text: Get Started with AWS
      :classes: btn-full btn-block stretched-link

   ---


   Use Coiled with GCP
   ^^^^^^^^^^^^^^^^^^^

   .. figure:: images/logo-gcp.png
      :width: 100%
      :alt: Use Coiled with Google Cloud Platform (GCP)

   +++

   .. link-button:: gcp-cli
      :type: ref
      :text: Get Started with GCP
      :classes: btn-full btn-block stretched-link

To configure Coiled to use a custom network configuration, e.g. your pre-existing VPC, or a different container registry for your Python environment, e.g. Docker Hub, see :doc:`manual_configure`.

Coiled makes it easy to deploy clusters in a way that's secure by default.
If you have questions about how we handle security, see our documentation about :doc:`security` (or :doc:`talk to us <support>`!).